/*
 *
 *  Copyright (C) 2006  The Exult Team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 *	This source file contains functions used in general services (selling of
 *	items, spells and healing).
 *
 *	Author: Marzo Junior
 *	Last Modified: 2006-02-27
 */


enum selling_result
{
	NO_QUANTITY							= 0,
	SELL_SUCCEEDED						= 1,
	CANNOT_CARRY						= 2,
	NOT_ENOUGH_GOLD						= 3
};

enum healing_type
{
	USE_HERBS							= 1,
	USE_BANDAGES						= 2,
	USE_POTIONS							= 3,
	USE_MAGIC							= 4
};

enum healing_prices
{
	SERVICE_NONE						= 0,
	SERVICE_CURE						= 1,
	SERVICE_HEAL						= 2,
	SERVICE_RESURRECT					= 3
};

var giveItemsToParty (var quantity, var shapenum, var quality, var framenum, var flag, var unknown)
{
	var startcount = PARTY->count_objects(shapenum, quality, framenum);
	var itemconts = UI_add_party_items(quantity, shapenum, quality, framenum, flag);
	
	if (UI_get_array_size(itemconts) == 1)
		return [0, 0];

	else
	{
		var finalcount = PARTY->count_objects(shapenum, quality, framenum);
		var delta = finalcount - startcount;

		var companions = removeFromArrayByIndex(itemconts, 1);
		
		if (companions)
		{
			if (quantity == 1)
				say("@Thou art so encumbered! Perhaps one of thy friends might be willing to carry this?@");
			else
				say("@Thou art so encumbered! Let me give some of this to thy friends.@");

			var msgs = ["@I'll help carry it.@", "@I will carry that.@", "@I will carry some.@", "@Let me help with that.@"];
			
			for (npc in companions)
				interjectIfPossible(UI_get_npc_number(npc), msgs[UI_get_random(UI_get_array_size(msgs))]);
		}
		
		if (delta > 0)
		{
			if (quantity == 1)
				say("@Since thou art so encumbered, I shall set this upon the ground.@");
			else if (delta == 1)
				say("@Since not one of you can hold another, I shall place this last remaining one upon the ground.@");
			else
				say("@Since thou art so encumbered, I shall place the remaining " + delta + " of these upon the ground.@");
			
			var pos = AVATAR->get_object_position();
			var groundobjs = shapenum->create_new_object();
			groundobjs->set_item_frame(framenum);
			groundobjs->set_item_quality(quality);
			if (delta > 1)
			{
				if (groundobjs->set_item_quantity(delta) == 0)
				{
					UI_update_last_created(pos);
					while (delta > 1)
					{
						groundobjs = shapenum->create_new_object();
						groundobjs->set_item_frame(framenum);
						groundobjs->set_item_quality(quality);
						UI_update_last_created(pos);
						delta = delta - 1;
					}
				}
				else
					UI_update_last_created(pos);
			}
			else
				UI_update_last_created(AVATAR->get_object_position());
		}
		return itemconts;
	}
}

var sellAmountToPartyExt (var shapenum, var framenum, var base_quant, var price, var max_quant, var min_quant, var money_shape)
{
	var amount;
	var finalquant;
	
	//Default to standard gold coins
	if (!money_shape)
		money_shape = SHAPE_GOLD;
	
	var partygold = PARTY->count_objects(money_shape, QUALITY_ANY, FRAME_ANY);
	
	if (max_quant == 0)
		amount = 1;
	else
		amount = UI_input_numeric_value(min_quant, max_quant, 1, 1);

	if (price > 1)
		finalquant = price * amount;
	else
		finalquant = amount;

	if (amount == 0)
		return NO_QUANTITY;
	else
	{
		if (partygold >= (base_quant * amount))
		{
			UI_remove_party_items((base_quant * amount), money_shape, QUALITY_ANY, SHAPE_ANY, true);
			giveItemsToParty(finalquant, shapenum, QUALITY_ANY, framenum, false, true);
			return SELL_SUCCEEDED;
		}
		else
			return NOT_ENOUGH_GOLD;
	}
}

var promptForPayment (var price, var dialog)
{
	if (price > 0)
	{
		say(dialog[2] + price + dialog[3]);
		if (askYesNo())
		{
			if (!hasGold(price))
			{
				say(dialog[4]);
				return false;
			}
		}
		else
		{
			say(dialog[5]);
			return false;
		}
	}
	return true;
}



